#ifndef I2C_Lichtsensor_h
#define I2C_Lichtsensor_h

#include <Arduino.h>

#include <Wire.h>

#define I2C_LS_ADR_J1_GND 0x44
#define I2C_LS_ADR_J1_VCC 0x45
#define I2C_LS_ADR_J1_SCL 0x46
#define I2C_LS_ADR_J1_SDA 0x47

#define I2C_LS_CONFIG_DEFAULT          0xc810     // Configdata for Register "Configuration"
                                          // Bit 15..12   Automatic Full-Scale Setting Mode
                                          // Bit 11       Conversion time field: 800ms
                                          // Bit 10..9    Mode of conversion: Shutdown
                                          // Bit 4        Latch field
#define I2C_LS_CONFIG_CONT_FULL_800MS  0xcc10     // Configdata for Register "Configuration"
                                          // Bit 15..12   Automatic Full-Scale Setting Mode
                                          // Bit 11       Conversion time field: 800ms
                                          // Bit 10..9    Mode of conversion: Continuous conversions
                                          // Bit 4        Latch field

typedef union {
  struct {
    uint8_t Faultcount   : 2;
    uint8_t Exponentmask : 1;
    uint8_t Polarity     : 1;
    uint8_t Latch        : 1;
    uint8_t FL           : 1; //FlagLow
    uint8_t FH           : 1; //FlagHigh
    uint8_t CRF          : 1; //ConversionReadyFlag
    uint8_t OVF          : 1; //OverFlowFlag
    uint8_t Mode         : 2;
    uint8_t CT           : 1; //ConversionTime
    uint8_t Range        : 4;
  };
  uint16_t config;
} I2C_LSConfig;

typedef enum
{
  I2C_LS_REG_RESULT          = 0x00,
  I2C_LS_REG_CONFIG          = 0x01,
  I2C_LS_REG_LOWLIMIT        = 0x02,
  I2C_LS_REG_HIGHLIMIT       = 0x03,
  I2C_LS_REG_MANUFACTURERID  = 0x7E,
  I2C_LS_REG_DEVICEID        = 0x7F,
} I2C_LSRegister_t;

typedef enum {
  RANGE_AUTO  = 0x0C,   // automatic full-scale
  RANGE_RES1  = 0x0D,   // reserved
  RANGE_RES2  = 0x0E,   // reserved
  RANGE_RES3  = 0x0F,   // reserved
} I2C_LSRange_t;

typedef enum {
  CT_100MS   = 0x00,   // 100ms conversion time
  CT_800MS   = 0x01,   // 800ms conversion time
} I2C_LSConversionTime_t;

typedef enum {
  MODE_SHUTDOWN    = 0x00,  // shutdown
  MODE_SINGLESHOT  = 0x01,  // single shot
  MODE_CONTINUOUS  = 0x02,  // continuous
  MODE_CONTINUOUS2 = 0x03,  // continuous
} I2C_LSMode_t;

typedef enum {
  OVF_ON          = 0x01,  // on
  OVF_OFF         = 0x00,  // off
} I2C_LSOverflowFlag_t;

typedef enum {
  CRF_ON          = 0x01, // on
  CRF_OFF         = 0x00, // off
} I2C_LSConversionReadyFlag_t;

typedef enum {
  FH_ON          = 0x01, // on
  FH_OFF         = 0x00, // off
} I2C_LSFlagHigh_t;

typedef enum {
  FL_ON          = 0x01, // on
  FL_OFF         = 0x00, // off
} I2C_LSFlagLow_t;

typedef enum {
  LATCH_ON       = 0x01, // on
  LATCH_OFF      = 0x00, // off
} I2C_LSLatch_t;

typedef enum {
  POL_LOW    = 0x00, // active low
  POL_HIGH   = 0x01, // active high
} I2C_LSPolarity_t;

typedef enum {
  EXP_MASK_ON    = 0x01, // on
  EXP_MASK_OFF   = 0x00, // off
} I2C_LSExpMask_t;

typedef enum {
  FAULT_COUNT_0     = 0x00, // one
  FAULT_COUNT_2     = 0x01, // two
  FAULT_COUNT_4     = 0x02, // four
  FAULT_COUNT_8     = 0x03, // eight
} I2C_LSFaultCount_t;


/**********************************************************
Klasse I2C-Lichtsensor
**********************************************************/
class I2C_Lichtsensor
{
private:
  
public:
  I2C_Lichtsensor();

  // Systemstart
  void begin(void);
  void begin(uint8_t);
  
  void reset(void);
  
  // Schreiben bzw. Lesen der Register
  void writeRegister(uint8_t, uint16_t);
  void writeRegister(I2C_LSRegister_t, uint16_t);
  uint16_t readRegister(uint8_t);
  uint16_t readRegister(I2C_LSRegister_t);
  
  uint16_t readResultReg(void);
  uint16_t readConfigReg(void);
  uint16_t readLowLimitReg(void);
  uint16_t readHighLimitReg(void);
  uint16_t readManufacturerId(void);
  uint16_t readDeviceId(void);
  
  uint32_t readLuxFixpoint(void);
  float readLuxFloat(void);
  I2C_LSConfig readConfig();
  
  void writeConfigReg(I2C_LSConfig);
  void writeConfigReg(uint16_t);
  void writeLowLimitReg(uint16_t);
  void writeHighLimitReg(uint16_t);
  void writeLowLimitLux(float);
  void writeHighLimitLux(float);

  uint16_t CovertU32ToExpMan(uint32_t);
  uint32_t CovertExpManToU32(uint16_t);
  float CovertExpManToFloat(uint16_t);
};

extern I2C_Lichtsensor I2C_LS;

#endif /* I2C_Lichtsensor_h */
