/******************************************************************************
Beispiel:      wait_for_readyflag

Beschreibung:  Dieses Beispiel zeigt die Verwendung des I2C-LS mit warten auf das
                ConversionReadyFlag.
               
Hinweis:       Die I2C-SlaveAdresse des Lichtsensors kann bei der Initialisierung
               übergeben werden, folgende Werte sind möglich.
                I2C_LS_ADR_J1_GND 0x00 (default)
                I2C_LS_ADR_J1_VCC 0x00
                I2C_LS_ADR_J1_SCL 0x00
                I2C_LS_ADR_J1_SDA 0x00
               Wird keine Adresse angegeben wird die default verwendet.
******************************************************************************/
#include <stdio.h>
#include "I2C-LS.h"


/******************************************************************************
Definitionen
******************************************************************************/

/******************************************************************************
globale Variablen
******************************************************************************/

/******************************************************************************
Funktionen
******************************************************************************/
void setup()
{
  /* die serielle Ausgabe initialisieren */
  Serial.begin(115200);
  
  /* I2C-LS initialisieren ohne I2C-Adresse*/  
  I2C_LS.begin();

  /* Lese Manufacturer ID vom Lichtsensor */
  Serial.print("Manufacturer ID: "); 
  Serial.println(I2C_LS.readRegister(I2C_LS_REG_MANUFACTURERID),HEX);

  /* Lese Device ID vom Lichtsensor */
  Serial.print("Device ID: ");
  Serial.println(I2C_LS.readRegister(I2C_LS_REG_DEVICEID),HEX);
  
  /* Initialisierung im Continouous Mode */
  I2C_LSConfig newconfig;
  newconfig.Faultcount   = FAULT_COUNT_0;
  newconfig.Exponentmask = EXP_MASK_OFF;
  newconfig.Polarity     = POL_LOW;
  newconfig.Latch        = LATCH_ON;
  newconfig.FL           = FL_OFF;  //readonly
  newconfig.FH           = FH_OFF;  //readonly
  newconfig.CRF          = CRF_OFF; //readonly
  newconfig.OVF          = OVF_OFF; //readonly
  newconfig.Mode         = MODE_CONTINUOUS;
  newconfig.CT           = CT_800MS;
  newconfig.Range        = RANGE_AUTO;
  
  I2C_LS.writeRegister( I2C_LS_REG_CONFIG, newconfig.config );
}

void loop()
{
  if( I2C_LS.readConfig().CRF )
  {
    /* Read I2C-LS */
    Serial.print("LUX:");
    Serial.println(I2C_LS.readLuxFloat(), 2);
  }
  else
  {
    Serial.println("CRF not set");
  }
  delay(100);
}